"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const oidc_client_1 = require("oidc-client");
exports.AuthContext = react_1.default.createContext({
    signIn: () => { },
    signOut: () => { },
});
exports.AuthProvider = (props) => {
    const { children, autoSignIn = true, onBeforeSignIn, onSignIn, onSignOut, location = window.location, } = props;
    let { userManager } = props;
    const [userData, setUserData] = react_1.useState(null);
    if (!userManager) {
        const { authority, clientId, redirectUri, responseType, scope } = props;
        userManager = new oidc_client_1.UserManager({
            authority,
            client_id: clientId,
            redirect_uri: redirectUri,
            silent_redirect_uri: redirectUri,
            post_logout_redirect_uri: redirectUri,
            response_type: responseType || 'code',
            scope: scope || 'openid',
            loadUserInfo: true,
        });
    }
    if (!userManager) {
        throw new Error('UserManager is missing.');
    }
    const signIn = () => __awaiter(void 0, void 0, void 0, function* () {
        userManager && userManager.signinRedirect();
    });
    react_1.useEffect(() => {
        const getUser = () => __awaiter(void 0, void 0, void 0, function* () {
            const searchParams = new URLSearchParams(location.search);
            const hashParams = new URLSearchParams(location.hash.replace('#', '?'));
            if (searchParams.get('code') ||
                searchParams.get('id_token') ||
                searchParams.get('session_state') ||
                hashParams.get('code') ||
                hashParams.get('id_token') ||
                hashParams.get('session_state')) {
                yield userManager.signinRedirectCallback();
                const user = yield userManager.getUser();
                setUserData(user);
                onSignIn && onSignIn(user);
                return;
            }
            const user = yield userManager.getUser();
            if ((!user || user === null) && autoSignIn) {
                if (onBeforeSignIn) {
                    onBeforeSignIn();
                }
                signIn();
            }
            else {
                setUserData(user);
            }
            return;
        });
        getUser();
    }, [location]);
    const context = {
        signIn,
        signOut: () => __awaiter(void 0, void 0, void 0, function* () {
            yield userManager.removeUser();
            setUserData(null);
            onSignOut && onSignOut();
        }),
        userData,
    };
    return (react_1.default.createElement(exports.AuthContext.Provider, { value: context }, children));
};
